@@ -10,11 +10,11 @@ Locale::CA - two letter codes for province identification in Canada and vice ver
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -22,13 +22,13 @@ our $VERSION = '0.02';
 
     my $u = Locale::CA->new();
 
+    # Returns the French names of the provinces if $LANG starts with 'fr'
     my $province = $u->{code2province}{$code};
     my $code  = $u->{province2code}{$province};
 
     my @province = $u->all_province_names;
     my @code  = $u->all_province_codes;
 
-
 =head1 SUBROUTINES/METHODS
 
 =head2 new
@@ -45,12 +45,17 @@ sub new {
 
 	my $self = {};
 
-	my $data = Data::Section::Simple::get_data_section('provinces');
+	my $data;
+	if(defined($ENV{'LANG'}) && ($ENV{'LANG'} =~ /^fr/)) {
+		$data = Data::Section::Simple::get_data_section('provinces_fr');
+	} else {
+		$data = Data::Section::Simple::get_data_section('provinces_en');
+	}
 
-	my @line = split "\n", $data;
+	my @line = split /\n/, $data;
 
 	for (@line) {
-		my($code, $province) = split ':';
+		my($code, $province) = split /:/;
 		$self->{code2province}{$code} = $province;
 		$self->{province2code}{$province} = $code;
 	}
@@ -94,7 +99,7 @@ province name as the value.
 
 =head1 SEE ALSO
 
-=head2 Locale::Country
+L<Locale::Country>
 
 =head1 AUTHOR
 
@@ -124,10 +129,6 @@ You can also look for information at:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Locale-CA>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Locale-CA>
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Locale-CA>
@@ -144,15 +145,15 @@ Based on L<Locale::US> - Copyright (c) 2002 - C<< $present >> Terrence Brannon.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012-2015 Nigel Horne.
+Copyright 2012-2020 Nigel Horne.
 
-This program is released under the following licence: GPL
+This program is released under the following licence: GPL2
 
 =cut
 
 1; # End of Locale::CA
 __DATA__
-@@ provinces
+@@ provinces_en
 AB:ALBERTA
 BC:BRITISH COLUMBIA
 MB:MANITOBA
@@ -165,4 +166,17 @@ PE:PRINCE EDWARD ISLAND
 QC:QUEBEC
 SK:SASKATCHEWAN
 YT:YUKON
+@@ provinces_fr
+AB:ALBERTA
+BC:COLOMBIE-BRITANNIQUE
+MB:MANITOBA
+NB:NOUVEAU-BRUNSWICK
+NL:TERRE-NEUVE-ET-LABRADOR
+NT:TERRITOIRES DU NORD-OUEST
+NS:NOUVELLE-ÉCOSSE
+ON:ONTARIO
+PE:ÎLE-DU-PRINCE-ÉDOUARD
+QC:QUÉBEC
+SK:SASKATCHEWAN
+YT:YUKON
 __END__
